//+------------------------------------------------------------------+
//|                                              myPickyBreakout.mq4 |
//|                                                 Copyright  2009 |
//|                                                                  |
//|                                                                  |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Copyright  2009, EarnForex.com"
#property link      "http://www.earnforex.com"

extern double Lots = 0.1;
extern double Slippage = 5;
extern int BarsToLookUp = 8;
extern int MinDiff = 3;
extern int MaxDuration = 5;

int Magic;
int Duration = 0;
int LastBars = 0;
int OT;

int init()
{
   Magic = Period()+59172491;
   return(0);
}

//+------------------------------------------------------------------+
//| Random entry expert advisor                                      |
//+------------------------------------------------------------------+
int start()
{
   if (AccountFreeMargin() < (Lots*2*1000))
   {
      //Print("Free margin level is too low.");
      return(0); 
   }

   if (Lots < 0.01)
   {
      Print("Lots below 0.01.");
      return(0);
   }

   //Wait for the new Bar in a chart.
	if (LastBars == Bars) return(0);
	else LastBars = Bars;

   int count = 0;
   int total = OrdersTotal();
   for (int pos = 0; pos < total; pos++)
   {
      if (OrderSelect(pos, SELECT_BY_POS) == false) continue;
      if ((OrderMagicNumber() == Magic) && (OrderSymbol() == Symbol()))
      {
         OT = OrderTicket();
         count = 1;
         Duration++;
      }
   }
   
   if (Duration == MaxDuration)
   {
      CloseOrder(OT);
      count = 0;
   }

   //Let's check if the last bar was highest high or lowest low in BarsToLookUp last bars
   int H = 0;
   int L = 0;
   for (int i = 2; i <= (BarsToLookUp+1); i++)
   {
      if ((High[1] - High[i]) > MinDiff*Point) H++;
      if ((Low[i] - Low[1]) > MinDiff*Point) L++;
   }
   
   //Trade only on Tuesdays, Wednesdays and Thursdays
   if ((DayOfWeek() < 2) || (DayOfWeek() > 4)) return(0);
   
   if ((H == BarsToLookUp) && (L == BarsToLookUp))
   {
      if (count > 0) return(0);
      if (Close[1] >= Open[1]) fBuy();
      else fSell();
   }
   else if (H == BarsToLookUp)
   {
      if ((count > 0) && (OrderType() == OP_SELL)) CloseOrder(OT);
      if (!((count > 0) && (OrderType() == OP_BUY))) fBuy();
   }
   else if (L == BarsToLookUp)
   {
      if ((count > 0) && (OrderType() == OP_BUY)) CloseOrder(OT);
      if (!((count > 0) && (OrderType() == OP_SELL))) fSell();
   }
}

//+------------------------------------------------------------------+
//| Buy                                                              |
//+------------------------------------------------------------------+
void fBuy()
{
	RefreshRates();
	int result = OrderSend(Symbol(),OP_BUY,Lots,Ask,Slippage,0,0,"myPickyBreakout",Magic,0); 
	if (result == -1)
	{
		int e = GetLastError();
		Print(e);
	}
	Duration = 0;
}

//+------------------------------------------------------------------+
//| Sell                                                             |
//+------------------------------------------------------------------+
void fSell()
{
	RefreshRates();
	int result = OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,0,0,"myPickyBreakout",Magic,0);
	if (result == -1)
	{
		int e = GetLastError();
		Print(e);
	}
	Duration = 0;
}

//+------------------------------------------------------------------+
//| Close all orders opened by this EA                               |
//+------------------------------------------------------------------+
void CloseOrder(int OT)
{
   RefreshRates();
   if (OrderType() == OP_BUY) OrderClose(OT, Lots, Bid, Slippage);
   if (OrderType() == OP_SELL) OrderClose(OT, Lots, Ask, Slippage);
   Duration = 0;
}


